/*
 * SPDX-FileCopyrightText: (C) 2017 Red Hat, Inc. (www.redhat.com)
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef E_ACCOUNTS_WINDOW_EDITORS_H
#define E_ACCOUNTS_WINDOW_EDITORS_H

#include <glib-object.h>

G_BEGIN_DECLS

void e_accounts_window_editors_type_register (GTypeModule *type_module);

G_END_DECLS

#endif /* E_ACCOUNTS_WINDOW_EDITORS_H */
