/*
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef E_MAIL_PARSER_TEXT_HIGHLIGHT_H
#define E_MAIL_PARSER_TEXT_HIGHLIGHT_H

#include <glib-object.h>

G_BEGIN_DECLS

void e_mail_parser_text_highlight_type_register (GTypeModule *type_module);

G_END_DECLS

#endif /* E_MAIL_PARSER_TEXT_HIGHLIGHT_H */
