/*
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef TEXT_HIGHLIGHT_H
#define TEXT_HIGHLIGHT_H

#include <glib-object.h>

G_BEGIN_DECLS

void	e_mail_formatter_text_highlight_type_register (GTypeModule *type_module);

G_END_DECLS

#endif /* TEXT_HIGHLIGHT_H */
