/*
 * SPDX-FileCopyrightText: (C) 1999-2008 Novell, Inc. (www.novell.com)
 * SPDX-License-Identifier: LGPL-2.1-or-later
 * SPDX-FileContributor: Bolian Yin <bolian.yin@sun.com>
 */

#if !defined (__E_UTIL_H_INSIDE__) && !defined (LIBEUTIL_COMPILATION)
#error "Only <e-util/e-util.h> should be included directly."
#endif

/* Evolution Accessibility
*/

#ifndef _EA_WIDGETS_H__
#define _EA_WIDGETS_H__

void e_calendar_item_a11y_init (void);

#endif /* _EA_WIDGETS_H__ */
