/*
 * SPDX-FileCopyrightText: (C) 1999-2008 Novell, Inc. (www.novell.com)
 * SPDX-License-Identifier: LGPL-2.1-or-later
 * SPDX-FileContributor: Leon Zhang <leon.zhang@sun.com>
 */

/* Evolution Accessibility
*/

#ifndef _EA_ADDRESSBOOK_H__
#define _EA_ADDRESSBOOK_H__

void eab_view_a11y_init (void);

#endif /* _EA_ADDRESSBOOK_H__ */
