
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "e-mail-enumtypes.h"
/* enumerations from "e-mail-enums.h" */
#include "e-mail-enums.h"
GType
e_mail_forward_style_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_FORWARD_STYLE_ATTACHED,
			  "E_MAIL_FORWARD_STYLE_ATTACHED",
			  "attached" },
			{ E_MAIL_FORWARD_STYLE_INLINE,
			  "E_MAIL_FORWARD_STYLE_INLINE",
			  "inline" },
			{ E_MAIL_FORWARD_STYLE_QUOTED,
			  "E_MAIL_FORWARD_STYLE_QUOTED",
			  "quoted" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailForwardStyle"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_mail_reply_style_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_REPLY_STYLE_UNKNOWN,
			  "E_MAIL_REPLY_STYLE_UNKNOWN",
			  "unknown" },
			{ E_MAIL_REPLY_STYLE_QUOTED,
			  "E_MAIL_REPLY_STYLE_QUOTED",
			  "quoted" },
			{ E_MAIL_REPLY_STYLE_DO_NOT_QUOTE,
			  "E_MAIL_REPLY_STYLE_DO_NOT_QUOTE",
			  "do-not-quote" },
			{ E_MAIL_REPLY_STYLE_ATTACH,
			  "E_MAIL_REPLY_STYLE_ATTACH",
			  "attach" },
			{ E_MAIL_REPLY_STYLE_OUTLOOK,
			  "E_MAIL_REPLY_STYLE_OUTLOOK",
			  "outlook" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailReplyStyle"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_mail_reply_type_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_REPLY_TO_SENDER,
			  "E_MAIL_REPLY_TO_SENDER",
			  "sender" },
			{ E_MAIL_REPLY_TO_RECIPIENT,
			  "E_MAIL_REPLY_TO_RECIPIENT",
			  "recipient" },
			{ E_MAIL_REPLY_TO_FROM,
			  "E_MAIL_REPLY_TO_FROM",
			  "from" },
			{ E_MAIL_REPLY_TO_ALL,
			  "E_MAIL_REPLY_TO_ALL",
			  "all" },
			{ E_MAIL_REPLY_TO_LIST,
			  "E_MAIL_REPLY_TO_LIST",
			  "list" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailReplyType"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_mail_reply_flags_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_MAIL_REPLY_FLAG_NONE,
			  "E_MAIL_REPLY_FLAG_NONE",
			  "none" },
			{ E_MAIL_REPLY_FLAG_FORCE_STYLE,
			  "E_MAIL_REPLY_FLAG_FORCE_STYLE",
			  "force-style" },
			{ E_MAIL_REPLY_FLAG_FORMAT_PLAIN,
			  "E_MAIL_REPLY_FLAG_FORMAT_PLAIN",
			  "format-plain" },
			{ E_MAIL_REPLY_FLAG_FORMAT_HTML,
			  "E_MAIL_REPLY_FLAG_FORMAT_HTML",
			  "format-html" },
			{ E_MAIL_REPLY_FLAG_TOP_POSTING,
			  "E_MAIL_REPLY_FLAG_TOP_POSTING",
			  "top-posting" },
			{ E_MAIL_REPLY_FLAG_BOTTOM_POSTING,
			  "E_MAIL_REPLY_FLAG_BOTTOM_POSTING",
			  "bottom-posting" },
			{ E_MAIL_REPLY_FLAG_TOP_SIGNATURE,
			  "E_MAIL_REPLY_FLAG_TOP_SIGNATURE",
			  "top-signature" },
			{ E_MAIL_REPLY_FLAG_BOTTOM_SIGNATURE,
			  "E_MAIL_REPLY_FLAG_BOTTOM_SIGNATURE",
			  "bottom-signature" },
			{ E_MAIL_REPLY_FLAG_FORCE_SENDER_REPLY,
			  "E_MAIL_REPLY_FLAG_FORCE_SENDER_REPLY",
			  "force-sender-reply" },
			{ E_MAIL_REPLY_FLAG_FORMAT_MARKDOWN,
			  "E_MAIL_REPLY_FLAG_FORMAT_MARKDOWN",
			  "format-markdown" },
			{ E_MAIL_REPLY_FLAG_FORMAT_MARKDOWN_PLAIN,
			  "E_MAIL_REPLY_FLAG_FORMAT_MARKDOWN_PLAIN",
			  "format-markdown-plain" },
			{ E_MAIL_REPLY_FLAG_FORMAT_MARKDOWN_HTML,
			  "E_MAIL_REPLY_FLAG_FORMAT_MARKDOWN_HTML",
			  "format-markdown-html" },
			{ E_MAIL_REPLY_FLAG_SKIP_INSECURE_PARTS,
			  "E_MAIL_REPLY_FLAG_SKIP_INSECURE_PARTS",
			  "skip-insecure-parts" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EMailReplyFlags"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

/* Generated data ends here */

