/*
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef E_SETTINGS_MEETING_STORE_H
#define E_SETTINGS_MEETING_STORE_H

#include <libebackend/libebackend.h>

/* Standard GObject macros */
#define E_TYPE_SETTINGS_MEETING_STORE \
	(e_settings_meeting_store_get_type ())
#define E_SETTINGS_MEETING_STORE(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST \
	((obj), E_TYPE_SETTINGS_MEETING_STORE, ESettingsMeetingStore))
#define E_SETTINGS_MEETING_STORE_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_CAST \
	((cls), E_TYPE_SETTINGS_MEETING_STORE, ESettingsMeetingStoreClass))
#define E_IS_SETTINGS_MEETING_STORE(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE \
	((obj), E_TYPE_SETTINGS_MEETING_STORE))
#define E_IS_SETTINGS_MEETING_STORE_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_TYPE \
	((cls), E_TYPE_SETTINGS_MEETING_STORE))
#define E_SETTINGS_MEETING_STORE_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS \
	((obj), E_TYPE_CaL_CONFIG_MEETING_STORE, ESettingsMeetingStoreClass))

G_BEGIN_DECLS

typedef struct _ESettingsMeetingStore ESettingsMeetingStore;
typedef struct _ESettingsMeetingStoreClass ESettingsMeetingStoreClass;
typedef struct _ESettingsMeetingStorePrivate ESettingsMeetingStorePrivate;

struct _ESettingsMeetingStore {
	EExtension parent;
	ESettingsMeetingStorePrivate *priv;
};

struct _ESettingsMeetingStoreClass {
	EExtensionClass parent_class;
};

GType		e_settings_meeting_store_get_type
						(void) G_GNUC_CONST;
void		e_settings_meeting_store_type_register
						(GTypeModule *type_module);

G_END_DECLS

#endif /* E_SETTINGS_MEETING_STORE_H */
